@@ -1,10 +1,9 @@
-from contextlib import ExitStack
+import os
 from textwrap import dedent
 from typing import Optional, Tuple
 
-from ..decorators import intercept_errors, run_subprocess
-from ..helpers.config import SymConfigFile
 from ..helpers.contexts import push_envs
+from ..helpers.keywords_to_options import keywords_to_options
 from ..helpers.params import get_ssh_user
 from ..helpers.ssh import ssh_key_and_config
 from ..helpers.tee import Tee
@@ -44,6 +43,8 @@ def run_ansible(
     ansible_sym_resource: Optional[str],
     binary: str = "ansible",
 ):
+    client.dprint(f"creating SSH artifacts")
+
     ssh_bin = str(create_ssh_bin(client))
     ssh_key, _ = ssh_key_and_config(client)
     args = [
@@ -53,6 +54,11 @@ def run_ansible(
         f"--private-key={ssh_key}",
         f"--scp-extra-args=-S '{ssh_bin}'",
         f"--sftp-extra-args=-S '{ssh_bin}'",
+        # Sometimes Ansible tries to use Paramiko instead of native SSH
+        # so we force it to use native SSH here
+        # See https://docs.ansible.com/ansible/latest/reference_appendices/faq.html#how-do-i-get-ansible-to-reuse-connections-enable-kerberized-ssh-or-have-ansible-pay-attention-to-my-local-ssh-config-file
+        # Note: it doesn't parse properly if there is a space
+        f"-cssh",
     ]
     envs = {
         "ANSIBLE_SSH_EXECUTABLE": ssh_bin,
@@ -74,5 +80,11 @@ def run_ansible(
     else:
         ansible_client = client
 
-    with push_envs(envs):
-        ansible_client.exec(*args, suppress_=True)
+    client.dprint(f"running ansible: client='{ansible_client._cli_options}', envs={envs}")
+
+    if client.log_dir:
+        with push_envs(envs):
+            ansible_client.exec(*args, suppress_=True)
+    else:
+        with push_envs({**envs, **ansible_client.get_creds()}):
+            os.execvp(args[0], keywords_to_options(args))
