@@ -28,13 +28,13 @@ ConfigKey = Literal["org", "email"]
 
 def xdg_config_home() -> Path:
     try:
-        return Path(os.environ["XDG_CONFIG_HOME"])
+        return Path(os.environ["XDG_CONFIG_HOME"]).resolve()
     except KeyError:
         return Path.home() / ".config"
 
 
 def sym_config_file(file_name: str) -> Path:
-    return xdg_config_home() / "sym" / file_name
+    return (xdg_config_home() / "sym" / file_name).resolve()
 
 
 class SymConfigFile:
@@ -209,6 +209,10 @@ class Config(MutableMapping[ConfigKey, Any]):
     def get_email(cls) -> str:
         return cls.instance()["email"]
 
+    @classmethod
+    def get_handle(cls) -> str:
+        return cls.get_email().split("@")[0]
+
     @classmethod
     def get_servers(cls) -> str:
         return cls.instance().get("servers", immutables.Map())
@@ -228,10 +232,12 @@ class Config(MutableMapping[ConfigKey, Any]):
                 return instance
 
     @classmethod
-    def check_instance_ttl(cls, instance: str, ttl: timedelta) -> Optional[str]:
+    def check_instance_ttl(
+        cls, instance: str, ttl: timedelta = timedelta(days=1)
+    ) -> bool:
         instance_config = cls.get_instance(instance)
         last_connect = instance_config.get("last_connection")
-        return last_connect and datetime.now() - last_connect < ttl
+        return bool(last_connect) and datetime.now() - last_connect < ttl
 
     @classmethod
     @contextmanager
