@@ -25,22 +25,25 @@ def config_option(
     return decorator
 
 
-def _resource_callback(ctx, resource: str, saml_client_name: str):
+def _resource_callback(ctx, resource: str, saml_client_name: str, throw=True):
     if resource is None:
         return None
     if not Config.is_logged_in():
         return resource
     saml_client = choose_saml_client(saml_client_name)
     if not saml_client.validate_resource(resource):
-        raise click.BadParameter(f"Invalid resource: {resource}")
+        if throw:
+            raise click.BadParameter(f"Invalid resource: {resource}")
+        else:
+            return None
     return resource
 
 
-def _resource_option_callback(ctx, resource: str):
-    return _resource_callback(ctx, resource, ctx.params["saml_client_name"])
+def _resource_option_callback(ctx, _param, resource: str):
+    return _resource_callback(ctx, resource, ctx.params["saml_client_name"], throw=False)
 
 
-def _resource_arg_callback(ctx, resource: str):
+def _resource_arg_callback(ctx, _param, resource: str):
     return _resource_callback(ctx, resource, ctx.parent.params["saml_client_name"])
 
 
@@ -77,3 +80,15 @@ def aws_profile_options(f):
         cls=EnvvarGroupedOption,
     )
     return ansible_aws_profile(ansible_sym_resource(f))
+
+
+def required_option(*args, if_, **kwargs):
+    def _callback(ctx, param: str, value: str):
+        if not value and if_(ctx):
+            raise click.exceptions.UsageError(f"{param} is required")
+        return value
+
+    def wrapper(f):
+        return click.option(*args, callback=_callback, **kwargs)(f)
+
+    return wrapper
