@@ -1,13 +1,12 @@
 import os
 import re
-import shlex
 import sys
 from datetime import timedelta
 from pathlib import Path
 from signal import SIGPIPE, signal
 from subprocess import CalledProcessError
 from textwrap import dedent
-from typing import Sequence
+from typing import List, Sequence
 
 from ..decorators import intercept_errors, retry, run_subprocess
 from ..errors import (
@@ -20,10 +19,9 @@ from ..errors import (
 )
 from ..helpers.boto import send_ssh_key, ssm_session
 from ..helpers.config import Config, SymConfigFile
-from ..helpers.contexts import push_envs
-from ..helpers.keywords_to_options import keywords_to_options
 from ..helpers.params import get_ssh_user
 from ..helpers.sym_group import SymGroup
+from ..saml_clients.saml_client import SAMLClient
 
 MissingPublicKeyPattern = re.compile(r"Permission denied \(.*publickey.*\)")
 TargetNotConnectedPattern = re.compile("TargetNotConnected")
@@ -34,7 +32,7 @@ SSHConfigPath = "ssh/config"
 SSHKeyPath = "ssh/key"
 
 
-def ssh_key_and_config(client: "SAMLClient"):
+def ssh_key_and_config(client: SAMLClient):
     ssh_key = SymConfigFile(file_name=SSHKeyPath, uid_scope=False)
     ssh_config = client.subconfig(SSHConfigPath, ssh_key=str(ssh_key))
     return (ssh_key, ssh_config)
@@ -79,9 +77,7 @@ def ssh_args(client, instance, port) -> tuple:
 
 
 @run_subprocess
-def _start_background_ssh_session(
-    client: "SAMLClient", instance: str, port: int, *command
-):
+def _start_background_ssh_session(client: SAMLClient, instance: str, port: int, *command):
     yield (
         *ssh_args(client, instance, port),
         {"f": True},
@@ -91,7 +87,7 @@ def _start_background_ssh_session(
 
 
 @run_subprocess
-def _start_ssh_session(client: "SAMLClient", instance: str, port: int, *command: str):
+def _start_ssh_session(client: SAMLClient, instance: str, port: int, *command: str):
     yield (*ssh_args(client, instance, port), *command)
 
 
@@ -101,10 +97,51 @@ def raw_ssh(*args):
     yield ("ssh", *args)
 
 
+def _parse_options_from_args(args: Sequence[str]):
+    opts = {}
+    for i, arg in enumerate(args):
+        if arg == "-o" and i + 1 < len(args):
+            k, v = re.split(r"=|\s+", args[i + 1])
+            opts[k.casefold()] = (v, i)
+    return opts
+
+
+def _on_ssh_error(client: SAMLClient, instance: str, args: Sequence[str]):
+    """
+    When there's an SSH error, we'll update our config to indicate we have an error in the
+    instance and we'll attempt to clear out any existing control path files.
+    """
+    Config.touch_instance(instance, error=True)
+    opts = _parse_options_from_args(args)
+    if (vi := opts.get("controlpath")) :
+        try:
+            os.unlink(vi[0])
+        except OSError as err:
+            client.dprint(f"Error cleaning up controlpath: {err}")
+
+
+def _preprocess_args(client: SAMLClient, instance: str, args: Sequence[str]) -> List[str]:
+    """
+    Checks the instance to make sure there is an existing SSH key that was used within the TTL. If not,
+    delete the ControlMaster and ControlPath arguments. Attempting to use an invalid ControlPath may
+    cause the SSH client to hang.
+    """
+    processed = list(args)
+    opts = _parse_options_from_args(args)
+    if not Config.check_instance_ttl(instance):
+        for opt in ("controlmaster", "controlpath"):
+            if (vi := opts.get(opt)) :
+                del processed[vi[1] : vi[1] + 2]
+
+        processed.extend(["-o", "ControlMaster=no"])
+        client.dprint("removed controlpath from ssh args")
+    return processed
+
+
 @retry(TargetNotConnected, delay=1, count=2)
 @retry(MissingPublicKey, delay=0, count=2)
 def start_ssh_session(
-    client: "SAMLClient",
+    client: SAMLClient,
     instance: str,
     port: int,
     *,
@@ -112,14 +149,16 @@ def start_ssh_session(
     command: Sequence[str] = [],
     wrap: bool = True,
 ):
+    args = _preprocess_args(client, instance=instance, args=args)
     ensure_ssh_key(client, instance, port)
+    client.dprint("starting SSH session")
     try:
         _start_ssh_session(client, instance, port, *args, *command)
     except CalledProcessError as err:
         if ConnectionClosedPattern.search(err.stderr):
             raise SuppressedError(err, echo=True) from err
         client.dprint(f"SSH Session Error: {err.stderr}")
-        Config.touch_instance(instance, error=True)
+        _on_ssh_error(client, instance, args=args)
         if MissingPublicKeyPattern.search(err.stderr):
             raise MissingPublicKey(err, get_ssh_user()) from err
         # If the ssh key path is cached then this doesn't get intercepted in ensure_ssh_key
@@ -150,18 +189,14 @@ def ensure_ssh_key(
 ):
     ssh_key, ssh_config = ssh_key_and_config(client)
     sym_cmd = f"PYTHONUNBUFFERED=1 sym {client.cli_options} ssh-session {client.resource} --instance %h --port %p"
-    ssh_cp = SymConfigFile(file_name="ssh/cp/.keep")
 
     if client.debug:
         mux_config = f"""
             ControlMaster no
         """
-
     else:
         mux_config = f"""
             ControlMaster auto
-            ControlPersist 15m
-            ControlPath {ssh_cp.path.parent}/%r@%h:%p
         """
 
     # fmt: off
@@ -182,7 +217,8 @@ def ensure_ssh_key(
     ))
     # fmt: on
 
-    ssh_cp.mkparents()
+    client.dprint("writing SSH key")
+
     maybe_gen_ssh_key(client)
 
     if Config.check_instance_ttl(instance, ttl):
@@ -199,6 +235,7 @@ def ensure_ssh_key(
             raise
         send_ssh_key(client, instance, ssh_key)
     else:
+        client.dprint("remote SSH key check succeeded")
         Config.touch_instance(instance)
 
 
@@ -219,4 +256,4 @@ def start_tunnel(client, instance: str, port: int):
     signal(SIGPIPE, handler)
 
     with ssm_session(client, instance, port) as command:
-        client.exec(*command)
+        client.exec(*command, suppress_=True)
