@@ -23,7 +23,7 @@ class Tee(object):
 
     @classmethod
     def path_for_fd(cls, log_dir, fd_name):
-        return Path(log_dir) / f"{os.getpid()}.{fd_name}.log"
+        return (Path(log_dir) / f"{os.getpid()}.{fd_name}.log").resolve()
 
     @classmethod
     def tee_command(cls, log_dir, command):
