@@ -1,5 +1,4 @@
 import importlib
-from collections.abc import Sequence
 from functools import wraps
 from pathlib import Path
 
@@ -30,7 +29,7 @@ def requires_all_imports(import_all):
 
 
 def wrap(val):
-    if isinstance(val, Sequence):
+    if isinstance(val, (list, tuple)):
         return val
     else:
         return (val,)
