@@ -1,8 +1,7 @@
 import os
 from configparser import ConfigParser
-from datetime import datetime
 from pathlib import Path
-from typing import Final, Iterator, Tuple
+from typing import Iterator, Tuple
 
 from ..decorators import intercept_errors, require_bins, run_subprocess
 from ..helpers.boto import get_identity
