@@ -6,7 +6,7 @@ from configparser import ConfigParser
 from datetime import datetime, timedelta
 from operator import attrgetter
 from pathlib import Path
-from typing import ClassVar, Final, Optional, Type
+from typing import ClassVar, Optional, Sequence, Type
 from urllib.parse import urlsplit
 
 from ..errors import CliError
@@ -26,7 +26,7 @@ class SAMLClient(ABC):
     resource: str
     options: "GlobalOptions"
 
-    config_file: Final[SymConfigFile]
+    config_file: SymConfigFile
 
     _config: Optional[ConfigParser]
     _session_exists: bool
@@ -102,11 +102,11 @@ class SAMLClient(ABC):
         return self._exec(*args, **kwargs)
 
     def _ensure_session(self, *, force: bool):
+        self.dprint(f"ensuring session, force={force}")
         self._exec("true", silence_stderr_=False, suppress_=True)
 
     def ensure_session(self, force=False):
         if not self._session_exists:
-            self.dprint(f"ensuring session, force={force}")
             self._ensure_session(force=force or self._creds_expiring())
             self._session_exists = True
 
@@ -124,8 +124,8 @@ class SAMLClient(ABC):
             **self._cli_options(), resource=self.resource, **deps, file_name=file_name
         )
 
-    def dprint(self, s: str):
-        self.options.dprint(s)
+    def dprint(self, *s: Sequence[str], **kwargs):
+        self.options.dprint(*s, **kwargs)
 
     def dconfig(self, config: ConfigParser):
         if self.debug:
@@ -167,7 +167,12 @@ class SAMLClient(ABC):
         return {k: v for k, v in env_vars if k in self._cred_env_vars}
 
     def _creds_expiring(self, buffer=timedelta(minutes=2)):
-        if (expires := self.get_creds().get("AWS_CREDENTIAL_EXPIRATION")) :
+        try:
+            creds = self.get_creds()
+        except Exception:
+            return True
+
+        if (expires := creds.get("AWS_CREDENTIAL_EXPIRATION")) :
             parsed = datetime.fromisoformat(expires)
             remaining = parsed - datetime.now(parsed.tzinfo)
             self.dprint(f"{remaining} remaining in creds session")
@@ -175,6 +180,8 @@ class SAMLClient(ABC):
         return False
 
     def write_creds(self, *, path: Path, profile: str):
+        self.dprint(f"writing creds, profile={profile}")
+
         if self._creds_expiring(buffer=timedelta(minutes=5)):
             self._ensure_session(force=True)
 
