@@ -12,6 +12,7 @@ from click.testing import CliRunner
 
 from sym.cli.helpers import boto
 from sym.cli.helpers.config import Config
+from sym.cli.helpers.envvar_option import reset_used
 from sym.cli.helpers.global_options import GlobalOptions
 from sym.cli.saml_clients.aws_okta import AwsOkta
 from sym.cli.saml_clients.aws_profile import AwsProfile
@@ -20,6 +21,8 @@ from sym.cli.sym import sym as click_command
 from sym.cli.tests.helpers.capture import CaptureCommand
 from sym.cli.tests.helpers.sandbox import Sandbox
 
+CustomOrgFixture = Callable[[str], ContextManager[None]]
+
 
 @pytest.fixture(autouse=True)
 def patch_is_setup(monkeypatch: MonkeyPatch):
@@ -41,9 +44,6 @@ def uuid_factory() -> Callable[[], UUID]:
     return uuid4
 
 
-CustomOrgFixture = Callable[[str], ContextManager[None]]
-
-
 @pytest.fixture
 def custom_org(monkeypatch: MonkeyPatch) -> CustomOrgFixture:
     @contextmanager
@@ -75,30 +75,65 @@ def click_context(sandbox):
 @pytest.fixture
 def click_setup(sandbox: Sandbox):
     @contextmanager
-    def context(set_org=True):
+    def context(set_org=True, set_client=True):
         runner = CliRunner()
         with runner.isolated_filesystem():
             with sandbox.push_xdg_config_home():
-                sandbox.create_binary(f"bin/{AwsOkta.binary}")
+                if set_client:
+                    sandbox.create_binary(f"bin/{AwsOkta.binary}")
                 with sandbox.push_exec_path():
                     if set_org:
                         Config.instance()["org"] = "sym"
                         Config.instance()["email"] = "y@symops.io"
                     yield runner
+        reset_used()
 
     return context
 
 
+def _env_str(creds):
+    return "\n".join([f"{k}={v}" for k, v in creds.items()]) + "\n"
+
+
 @pytest.fixture
-def saml_client(sandbox: Sandbox, monkeypatch: MonkeyPatch):
+def creds_env():
+    return {
+        "AWS_REGION": "us-east-2",
+        "AWS_ACCESS_KEY_ID": "ASIA4GNNUMIHHBPSAQC3",
+        "AWS_SECRET_ACCESS_KEY": "xxx",
+        "AWS_SESSION_TOKEN": "xxx",
+        "AWS_OKTA_SESSION_EXPIRATION": "1600494616",
+    }
+
+
+@pytest.fixture
+def creds_env_str(creds_env):
+    return _env_str(creds_env)
+
+
+@pytest.fixture
+def env_creds(creds_env_str, capture_command: CaptureCommand):
+    capture_command.register_output(r"env", creds_env_str)
+
+
+@pytest.fixture
+def fake_creds_env():
+    return {
+        "AWS_REGION": "foobar",
+        "AWS_FOOBAR": "baz",
+        "AWS_OKTA_SESSION_EXPIRATION": "1600494616",
+    }
+
+
+@pytest.fixture
+def fake_creds_env_str(fake_creds_env):
+    return _env_str(fake_creds_env)
+
+
+@pytest.fixture
+def saml_client(sandbox: Sandbox, monkeypatch: MonkeyPatch, creds_env):
     def get_creds(self):
-        return {
-            "AWS_REGION": "us-east-2",
-            "AWS_ACCESS_KEY_ID": "ASIA4GNNUMIHHBPSAQC3",
-            "AWS_SECRET_ACCESS_KEY": "xxx",
-            "AWS_SESSION_TOKEN": "xxx",
-            "AWS_OKTA_SESSION_EXPIRATION": "1600494616",
-        }
+        return dict(creds_env)
 
     monkeypatch.setattr(AwsOkta, "get_creds", get_creds)
 
@@ -107,6 +142,12 @@ def saml_client(sandbox: Sandbox, monkeypatch: MonkeyPatch):
         return AwsOkta("test", options=GlobalOptions(debug=False))
 
 
+@pytest.fixture
+def ssm_bins(sandbox: Sandbox):
+    for binary in ["aws", "session-manager-plugin", "ssh"]:
+        sandbox.create_binary(f"bin/{binary}")
+
+
 @pytest.fixture
 def boto_stub(monkeypatch: MonkeyPatch):
     stubs = {}
@@ -136,3 +177,7 @@ def setup_context():
     with click.Context(click_command) as ctx:
         ctx.obj = GlobalOptions(saml_client_type=AwsProfile)
         yield
+
+
+def empty_saml_client():
+    return AwsProfile("test", options=GlobalOptions())
